@@ -10,7 +10,7 @@ use Scalar::Util qw(blessed);
 
 BEGIN {
 	$MooseX::XSAccessor::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::XSAccessor::VERSION   = '0.002';
+	$MooseX::XSAccessor::VERSION   = '0.003';
 }
 
 use Moose::Exporter;
@@ -86,7 +86,6 @@ class.
 
 =end private
 
-
 The use of the following features of Moose attributes prevents a reader
 from being accelerated:
 
@@ -124,6 +123,11 @@ Weak references
 An C<rw> accessor is effectively a reader and a writer glued together, so
 both of the above lists apply.
 
+Predicates can always be accelerated, provided you're using Class::XSAccessor
+1.17 or above.
+
+Clearers can not be accelerated (as of current versions of Class::XSAccessor).
+
 =head2 Functions
 
 This module also provides one function, which is not exported so needs to be
